==> etsi-mec-sandbox-v1.5.0.zip: etsi-mec-sandbox-v1.5.0/README.md <==
![AdvantEDGE-logo](https://github.com/InterDigitalInc/AdvantEDGE/wiki/images/AdvantEDGE-logo_Blue-01.png)

------
AdvantEDGE is a Mobile Edge Emulation Platform (MEEP) that runs on Docker & Kubernetes.<br><br>

AdvantEDGE provides an emulation environment, enabling experimentation with Edge Computing Technologies, Applications, and Services.  The platform facilitates exploring edge / fog deployment models and their impact on applications and services in short and agile iterations.

## Motivation

- [x] **Accelerate Mobile Edge Computing adoption**
- [x] **Help Discover new edge application use cases & services**
- [x] **Help answer questions such as:**
  - Where should my application components be located in the edge network?
  - How do network characteristics (such as latency, jitter, and packet loss) impact my application or service?
  - How will my application behave when the user moves within and across access networks?

## Getting Started

Complete AdvantEDGE documentation is available in the [AdvantEDGE Wiki](https://github.com/InterDigitalInc/AdvantEDGE/wiki)

To get started using AdvantEDGE, the following steps are needed:
- Set up runtime environment (Ubuntu/Dockers/Kubernetes/Helm)
- Clone AdvantEDGE repo
- Install & Configure meepctl tool
- Deploy AdvantEDGE micro-services

Step-by-step details are available in the [Wiki](https://github.com/InterDigitalInc/AdvantEDGE/wiki#getting-started)

## How to Contribute
**NEW!** <br>
Starting June 2020 with v1.5 release, we can start accepting contributions to the project.

If you like this project and would like to participate in its evolution, you can find information on contributing [here](https://github.com/InterDigitalInc/AdvantEDGE/CONTRIBUTING.md)

We still welcome feedback and improvement suggestions via Git issue in the repo for bugs or request enhancements.

Hope to hear from you...

## Licensing

AdvantEDGE is licensed under under the [Apache License, Version 2.0](https://github.com/InterDigitalInc/AdvantEDGE/blob/master/LICENSE)

==> etsi-mec-sandbox-v1.6.0.zip: etsi-mec-sandbox-v1.6.0/README.md <==
![AdvantEDGE-logo](https://github.com/InterDigitalInc/AdvantEDGE/wiki/images/AdvantEDGE-logo_Blue-01.png)

------

> **_NEW!_**  --  Reaching out to the team is now easier than ever:  -- just initiate a [discussion](https://github.com/InterDigitalInc/AdvantEDGE/discussions)

------

AdvantEDGE is a Mobile Edge Emulation Platform (MEEP) that runs on Docker & Kubernetes.

AdvantEDGE provides an emulation environment, enabling experimentation with Edge Computing Technologies, Applications, and Services.  The platform facilitates exploring edge / fog deployment models and their impact on applications and services in short and agile iterations.

## Motivation

- [x] **Accelerate Mobile Edge Computing adoption**
- [x] **Help Discover new edge application use cases & services**
- [x] **Help answer questions such as:**
  - Where should my application components be located in the edge network?
  - How do network characteristics (such as latency, jitter, and packet loss) impact my application or service?
  - How will my application behave when the user moves within and across access networks?

## Getting Started

Complete AdvantEDGE documentation is available in the [AdvantEDGE Wiki](https://github.com/InterDigitalInc/AdvantEDGE/wiki)

To get started using AdvantEDGE, the following steps are needed:
- Set up runtime environment (Ubuntu/Dockers/Kubernetes/Helm)
- Clone AdvantEDGE repo
- Install & Configure meepctl tool
- Deploy AdvantEDGE micro-services

Step-by-step details are available in the [Wiki](https://github.com/InterDigitalInc/AdvantEDGE/wiki#getting-started)

## How to Contribute
As of June 2020, we can accept contributions to the project.

If you like this project and would like to participate in its evolution, you can find information on contributing [here](https://github.com/InterDigitalInc/AdvantEDGE/blob/master/CONTRIBUTING.md)

We still welcome feedback and improvement suggestions via Git issue in the repo for bugs or request enhancements.

Hope to hear from you...

## Licensing

AdvantEDGE is licensed under under the [Apache License, Version 2.0](https://github.com/InterDigitalInc/AdvantEDGE/blob/master/LICENSE)
